@@ -1,9 +1,9 @@
 package IRC::Toolkit::Case;
 {
-  $IRC::Toolkit::Case::VERSION = '0.086000';
+  $IRC::Toolkit::Case::VERSION = '0.087000';
 }
 use strictures 1;
-
+no warnings 'once';
 use Carp 'carp';
 
 use parent 'Exporter::Tiny';
@@ -11,8 +11,17 @@ our @EXPORT = qw/
   lc_irc
   uc_irc
   eq_irc
+
+  rfc1459
+
+  irc_str
 /;
 
+
+use Sub::Infix;
+*rfc1459 = &infix(sub { eq_irc( $_[0], $_[1], 'rfc1459' ) });
+
+
 ## The prototypes are unfortunate, but I pulled these out of an old
 ## and very large bot project ... and was too scared to remove them.
 
@@ -54,7 +63,7 @@ sub uc_irc ($;$) {
       last CASE
     }
 
-    if ($casemap eq 'strict-rfc1459') {
+    if ($casemap eq 'strict-rfc1459' || $casemap eq 'strict') {
       $string =~ tr/a-z{}|/A-Z[]\\/;
       last CASE
     }
@@ -78,6 +87,11 @@ sub eq_irc ($$;$) {
   1
 }
 
+sub irc_str {
+  require IRC::Toolkit::Case::MappedString;
+  IRC::Toolkit::Case::MappedString->new(@_)
+}
+
 
 1;
 
@@ -99,6 +113,11 @@ IRC::Toolkit::Case - IRC case-folding utilities
     ...
   }
 
+  # Or use the '|rfc1459|' operator if using RFC1459 rules:
+  if ($first |rfc1459| $second) {
+
+  }
+
 =head1 DESCRIPTION
 
 IRC case-folding utilities.
@@ -117,6 +136,15 @@ default to RFC1459 rules.
 If you're building a class that tracks an IRC casemapping and manipulates
 strings accordingly, you may also want to see L<IRC::Toolkit::Role::CaseMap>.
 
+=head2 rfc1459 operator
+
+The infix operator C<|rfc1459|> is provided as a convenience for string
+comparison using RFC1459 rules:
+
+  if ($first |rfc1459| $second) { ... }
+  # Same as:
+  if (eq_irc($first, $second)) { ... }
+
 =head2 lc_irc
 
 Takes a string and an optional casemap.
@@ -136,6 +164,20 @@ Takes a pair of strings and an optional casemap.
 Returns boolean true if the strings are equal 
 (per the rules specified by the given casemap).
 
+=head2 irc_str
+
+  my $str = irc_str( strict => 'Nick^[Abc]' );
+  if ( $str eq 'nick^{abc}' ) {
+    # true
+  }
+
+Takes a casemap and string; if only one argument is provided, it is taken to
+be the string and a C<rfc1459> casemap is assumed.
+
+Produces overloaded objects (see L<IRC::Toolkit::Case::MappedString>) that can
+be stringified or compared; string comparison operators use the specified
+casemap.
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
